@@ -5,19 +5,25 @@ from edc_auth.auth_objects import (
     NURSE_ROLE,
 )
 from edc_auth.site_auths import site_auths
+from edc_auth.utils import remove_default_model_permissions_from_edc_permissions
 
-from .auth_objects import REVIEW
+REVIEW = "REVIEW"
+
+site_auths.add_post_update_func(
+    "edc_review_dashboard", remove_default_model_permissions_from_edc_permissions
+)
 
 site_auths.add_custom_permissions_tuples(
-    model="edc_dashboard.dashboard",
+    model="edc_review_dashboard.edcpermissions",
     codename_tuples=[
         (
-            "edc_dashboard.view_subject_review_listboard",
+            "edc_review_dashboard.view_subject_review_listboard",
             "Can view Subject review listboard",
         )
     ],
 )
-site_auths.add_group("edc_dashboard.view_subject_review_listboard", name=REVIEW)
+site_auths.add_group("edc_review_dashboard.view_subject_review_listboard", name=REVIEW)
+
 site_auths.update_role(REVIEW, name=AUDITOR_ROLE)
 site_auths.update_role(REVIEW, name=CLINICIAN_ROLE)
 site_auths.update_role(REVIEW, name=CLINICIAN_SUPER_ROLE)
