@@ -1,9 +1,7 @@
 from dateutil.relativedelta import FR, MO, SA, SU, TH, TU, WE
 from django.apps import AppConfig as DjangoAppConfig
-from edc_appointment.apps import AppConfig as BaseEdcAppointmentAppConfig
 from edc_facility.apps import AppConfig as BaseEdcFacilityAppConfig
 from edc_metadata.apps import AppConfig as BaseEdcMetadataAppConfig
-from edc_visit_tracking.apps import AppConfig as BaseEdcVisitTrackingAppConfig
 
 
 class AppConfig(DjangoAppConfig):
@@ -11,12 +9,6 @@ class AppConfig(DjangoAppConfig):
     verbose_name = "review_dashboard_app"
 
 
-class EdcVisitTrackingAppConfig(BaseEdcVisitTrackingAppConfig):
-    visit_models = {
-        "review_dashboard_app": ("subject_visit", "review_dashboard_app.subjectvisit")
-    }
-
-
 class EdcFacilityAppConfig(BaseEdcFacilityAppConfig):
     definitions = {
         "7-day-clinic": dict(
@@ -27,9 +19,5 @@ class EdcFacilityAppConfig(BaseEdcFacilityAppConfig):
     }
 
 
-class EdcAppointmentAppConfig(BaseEdcAppointmentAppConfig):
-    pass
-
-
 class EdcMetadataAppConfig(BaseEdcMetadataAppConfig):
     reason_field = {"review_dashboard_app.subjectvisit": "reason"}
